# Changelog

## 1.0.3 (2025-12-03)

Full Changelog: [v1.0.2...v1.0.3](https://github.com/Blooio/blooio-python-sdk/compare/v1.0.2...v1.0.3)

### Bug Fixes

* ensure streams are always closed ([3a2cc70](https://github.com/Blooio/blooio-python-sdk/commit/3a2cc70ea5a7a492ae9b404e6305bd5deb7d3e0d))


### Chores

* **deps:** mypy 1.18.1 has a regression, pin to 1.17 ([a7853af](https://github.com/Blooio/blooio-python-sdk/commit/a7853af591c6af19cce4ed7c04fe953dbfb957bb))
* **docs:** use environment variables for authentication in code snippets ([9558d99](https://github.com/Blooio/blooio-python-sdk/commit/9558d99532c57a9a4b712a5ed575ebdae753a052))
* update lockfile ([e7f0120](https://github.com/Blooio/blooio-python-sdk/commit/e7f0120b8b56fb9b73bda0ebc32510fef7fe6701))

## 1.0.2 (2025-11-22)

Full Changelog: [v1.0.1...v1.0.2](https://github.com/Blooio/blooio-python-sdk/compare/v1.0.1...v1.0.2)

### Bug Fixes

* compat with Python 3.14 ([2c8e789](https://github.com/Blooio/blooio-python-sdk/commit/2c8e789b083bf5f4049214cc475de071495f902f))
* **compat:** update signatures of `model_dump` and `model_dump_json` for Pydantic v1 ([efacbb6](https://github.com/Blooio/blooio-python-sdk/commit/efacbb66a2b9329eb4461561e38f5838d37b1087))


### Chores

* add Python 3.14 classifier and testing ([dd2ed6b](https://github.com/Blooio/blooio-python-sdk/commit/dd2ed6bc4918462d334a869270f496e5dce653a5))
* **package:** drop Python 3.8 support ([19cbcd0](https://github.com/Blooio/blooio-python-sdk/commit/19cbcd0ce4d5dd3626fff4cd02094b3d9bf69f48))

## 1.0.1 (2025-11-04)

Full Changelog: [v1.0.0...v1.0.1](https://github.com/Blooio/blooio-python-sdk/compare/v1.0.0...v1.0.1)

### Bug Fixes

* **client:** close streams without requiring full consumption ([145afcd](https://github.com/Blooio/blooio-python-sdk/commit/145afcd5e6669103ed6066ebcfae0c4930f3d82b))


### Chores

* **internal/tests:** avoid race condition with implicit client cleanup ([3d808c8](https://github.com/Blooio/blooio-python-sdk/commit/3d808c8070ccca32d19887b0dddf965ea53bcd04))
* **internal:** grammar fix (it's -&gt; its) ([be60d3b](https://github.com/Blooio/blooio-python-sdk/commit/be60d3b2f9cd4f51c92472a16e8153595aa1c8dd))

## 1.0.0 (2025-10-17)

Full Changelog: [v0.0.1...v1.0.0](https://github.com/Blooio/blooio-python-sdk/compare/v0.0.1...v1.0.0)

### Chores

* configure new SDK language ([8f81881](https://github.com/Blooio/blooio-python-sdk/commit/8f8188186e7367438a7d5f311a21499384056275))
* update SDK settings ([3a67436](https://github.com/Blooio/blooio-python-sdk/commit/3a67436282797fe0406e4cbcf4ecce9d523d8b5e))
* update SDK settings ([c8fc4f6](https://github.com/Blooio/blooio-python-sdk/commit/c8fc4f61c3028509ea520a92b56246a29edd9b3e))
